PerflutterNavigatorObserver class

Navigator observer that forwards route changes to PerflutterTracker.

Inheritance

Constructors

PerflutterNavigatorObserver()
Creates the observer.

Properties

hashCode int
The hash code for this object.
no setterinherited
The navigator that the observer is observing, if any.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didChangeTabRoute(TabPageRoute route, TabPageRoute previousRoute) → void
called when tab route reactivates
didChangeTop(Route topRoute, Route? previousTopRoute) → void
The top most route has changed.
inherited
didInitTabRoute(TabPageRoute route, TabPageRoute? previousRoute) → void
called when a tab route activates
didPop(Route route, Route? previousRoute) → void
The Navigator popped route.
override
didPush(Route route, Route? previousRoute) → void
The Navigator pushed route.
override
didRemove(Route route, Route? previousRoute) → void
The Navigator removed route.
inherited
didReplace({Route? newRoute, Route? oldRoute}) → void
The Navigator replaced oldRoute with newRoute.
inherited
didStartUserGesture(Route route, Route? previousRoute) → void
The Navigator's routes are being moved by a user gesture.
inherited
didStopUserGesture() → void
User gesture is no longer controlling the Navigator.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited