ScreenPerformanceData class
Aggregated performance metrics collected for a single screen.
Constructors
- ScreenPerformanceData(String screenName)
-
Creates a record for
screenNameand starts timing immediately.
Properties
- droppedFrames ↔ int
-
Frames where UI or Raster time exceeded the frame budget.
getter/setter pair
- duration → Duration
-
Elapsed time for this screen visit or aggregated visits.
no setter
- endTime ↔ DateTime?
-
Timestamp when this screen record ended.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- peakMemoryMb ↔ double
-
Peak process memory usage in MB captured for this screen.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenName → String
-
Route or screen name.
final
- startTime → DateTime
-
Timestamp when this screen record started.
final
- totalFrames ↔ int
-
Total frames rendered while this screen was active.
getter/setter pair
- visitCount ↔ int
-
Number of visits included in this record.
getter/setter pair
Methods
-
aggregate(
ScreenPerformanceData other) → ScreenPerformanceData - Combines this record with another visit of the same screen.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordFrame(
FrameTiming timing, int frameBudgetMicros) → void - Records a frame timing sample.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited